about summary refs log tree commit diff
path: root/.config/zsh/history.zsh
diff options
context:
space:
mode:
authorStarfall <us@starfall.systems>2021-10-19 11:19:08 -0500
committerStarfall <us@starfall.systems>2021-10-19 11:19:08 -0500
commit17aa04429787baf24511eec76f4c84842d185c67 (patch)
tree43a1662019e3b20e39489731f9ddeb4cccf43219 /.config/zsh/history.zsh
parent23e334fa578995205aa516b0cdd7e77e31c1acff (diff)
zsh: share history and deduplicate at all times
Diffstat (limited to '.config/zsh/history.zsh')
-rw-r--r--.config/zsh/history.zsh12
1 files changed, 7 insertions, 5 deletions
diff --git a/.config/zsh/history.zsh b/.config/zsh/history.zsh
index 3bbe525..702cfae 100644
--- a/.config/zsh/history.zsh
+++ b/.config/zsh/history.zsh
@@ -2,8 +2,10 @@
 HISTFILE=${ZDOTDIR:-$HOME}/.zsh_history
 HISTSIZE=10000
 SAVEHIST=$HISTSIZE
-setopt extended_history   # write timestamp
-setopt inc_append_history # write always, not just at end of session
-setopt hist_ignore_space  # add leading space to hide from history
-setopt hist_ignore_dups   # deduplicate commands run twice in a row
-setopt hist_verify        # confirm before executing
+# setopt extended_history     # write timestamp (redundant with share_history?)
+# setopt inc_append_history   # write always, not just at end of session (redundant and exclusive with share_history)
+setopt hist_ignore_space    # add leading space to hide from history
+setopt hist_ignore_dups     # deduplicate commands run twice in a row
+setopt hist_ignore_all_dups # deduplicate entire history file
+setopt hist_verify          # confirm before executing
+setopt share_history        # import all of history in new sessions